package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.ConfigGlobalFirePointDao;
import com.xkrs.dao.ConfigGlobalSMSDao;
import com.xkrs.dao.ConfigGlobalUserDao;
import com.xkrs.model.entity.ConfigGlobalFirePointEntity;
import com.xkrs.model.entity.ConfigGlobalSMSEntity;
import com.xkrs.model.entity.ConfigGlobalUserEntity;
import com.xkrs.service.ConfigGlobalService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 全局配置服务
 */
@Service
public class ConfigGlobalServiceImpl implements ConfigGlobalService {

    private final Locale locale = LocaleContextHolder.getLocale();

    /**
     * 用户全局配置信息
     */
    @Resource
    private ConfigGlobalUserDao configGlobalUserDao;

    /**
     * 火情信息全局配置信息
     */
    @Resource
    private ConfigGlobalFirePointDao configGlobalFirePointDao;

    /**
     * 短信全局配置信息
     */
    @Resource
    private ConfigGlobalSMSDao configGlobalSMSDao;

    /**
     * 用户全局配置服务
     */
    @Override
    public String configGlobalUser(Map<String, Long> configMap) {
        if (configMap == null) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_NULL, "配置失败", locale);
        }
        Long loginAbleWhenExpired = configMap.get("LoginAbleWhenExpired");
        List<ConfigGlobalUserEntity> configGlobalUserEntityList = configGlobalUserDao.findAll();
        if (configGlobalUserEntityList.isEmpty()) {
            ConfigGlobalUserEntity configGlobalUserEntity = new ConfigGlobalUserEntity();
            configGlobalUserEntity.setLoginAbleWhenExpired(loginAbleWhenExpired);
            configGlobalUserDao.save(configGlobalUserEntity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
        }
        ConfigGlobalUserEntity configGlobalUserEntity = configGlobalUserEntityList.get(0);
        if (loginAbleWhenExpired != null) {
            if (configGlobalUserEntity.getLoginAbleWhenExpired() == null || configGlobalUserEntity.getLoginAbleWhenExpired().longValue() != loginAbleWhenExpired.longValue()) {
                configGlobalUserEntity.setLoginAbleWhenExpired(loginAbleWhenExpired);
            }
        }
        configGlobalUserDao.save(configGlobalUserEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
    }

    /**
     * 火情信息全局配置服务
     */
    @Override
    public String configGlobalFirePoint(Map<String, Long> configMap) {
        if (configMap == null) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_NULL, "配置失败", locale);
        }
        Long todayAbleWhenExpired = configMap.get("TodayAbleWhenExpired");
        Long historyAbleWhenExpired = configMap.get("HistoryAbleWhenExpired");
        Long statisticsAbleWhenExpired = configMap.get("StatisticsAbleWhenExpired");
        Long navigateAbleWhenExpired = configMap.get("NavigateAbleWhenExpired");
        List<ConfigGlobalFirePointEntity> configGlobalFirePointEntityList = configGlobalFirePointDao.findAll();
        if (configGlobalFirePointEntityList.isEmpty()) {
            ConfigGlobalFirePointEntity configGlobalFirePointEntity = new ConfigGlobalFirePointEntity();
            configGlobalFirePointEntity.setTodayAbleWhenExpired(todayAbleWhenExpired);
            configGlobalFirePointEntity.setHistoryAbleWhenExpired(historyAbleWhenExpired);
            configGlobalFirePointEntity.setStatisticsAbleWhenExpired(statisticsAbleWhenExpired);
            configGlobalFirePointEntity.setNavigateAbleWhenExpired(navigateAbleWhenExpired);
            configGlobalFirePointDao.save(configGlobalFirePointEntity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
        }
        ConfigGlobalFirePointEntity configGlobalFirePointEntity = configGlobalFirePointEntityList.get(0);
        if (todayAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getTodayAbleWhenExpired() == null || configGlobalFirePointEntity.getTodayAbleWhenExpired().longValue() != todayAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setTodayAbleWhenExpired(todayAbleWhenExpired);
            }
        }
        if (historyAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getHistoryAbleWhenExpired() == null || configGlobalFirePointEntity.getHistoryAbleWhenExpired().longValue() != historyAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setHistoryAbleWhenExpired(historyAbleWhenExpired);
            }
        }
        if (statisticsAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getStatisticsAbleWhenExpired() == null || configGlobalFirePointEntity.getStatisticsAbleWhenExpired().longValue() != statisticsAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setStatisticsAbleWhenExpired(statisticsAbleWhenExpired);
            }
        }
        if (navigateAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getNavigateAbleWhenExpired() == null || configGlobalFirePointEntity.getNavigateAbleWhenExpired().longValue() != navigateAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setNavigateAbleWhenExpired(navigateAbleWhenExpired);
            }
        }
        configGlobalFirePointDao.save(configGlobalFirePointEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
    }

    /**
     * 短信全局配置服务
     */
    @Override
    public String configGlobalSMS(Map<String, Long> configMap) {
        if (configMap == null) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_NULL, "配置失败", locale);
        }
        Long smsAbleWhenExpired = configMap.get("SmsAbleWhenExpired");
        Long proAnAbleBeforeExpired = configMap.get("ProAnAbleBeforeExpired");
        Long proAnDayBeforeExpired = configMap.get("ProAnDayBeforeExpired");
        Long cityAnAbleBeforeExpired = configMap.get("CityAnAbleBeforeExpired");
        Long cityAnDayBeforeExpired = configMap.get("CityAnDayBeforeExpired");
        Long countyAnAbleBeforeExpired = configMap.get("CountyAnAbleBeforeExpired");
        Long countyAnDayBeforeExpired = configMap.get("CountyAnDayBeforeExpired");
        Long streetAnAbleBeforeExpired = configMap.get("StreetAnAbleBeforeExpired");
        Long streetAnDayBeforeExpired = configMap.get("StreetAnDayBeforeExpired");
        List<ConfigGlobalSMSEntity> configGlobalSMSEntityList = configGlobalSMSDao.findAll();
        if (configGlobalSMSEntityList.isEmpty()) {
            ConfigGlobalSMSEntity configGlobalSMSEntity = new ConfigGlobalSMSEntity();
            configGlobalSMSEntity.setSmsAbleWhenExpired(smsAbleWhenExpired);
            configGlobalSMSEntity.setProAnAbleBeforeExpired(proAnAbleBeforeExpired);
            configGlobalSMSEntity.setProAnDayBeforeExpired(proAnDayBeforeExpired);
            configGlobalSMSEntity.setCityAnAbleBeforeExpired(cityAnAbleBeforeExpired);
            configGlobalSMSEntity.setCityAnDayBeforeExpired(cityAnDayBeforeExpired);
            configGlobalSMSEntity.setCountyAnAbleBeforeExpired(countyAnAbleBeforeExpired);
            configGlobalSMSEntity.setCountyAnDayBeforeExpired(countyAnDayBeforeExpired);
            configGlobalSMSEntity.setStreetAnAbleBeforeExpired(streetAnAbleBeforeExpired);
            configGlobalSMSEntity.setStreetAnDayBeforeExpired(streetAnDayBeforeExpired);
            configGlobalSMSDao.save(configGlobalSMSEntity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
        }
        ConfigGlobalSMSEntity configGlobalSMSEntity = configGlobalSMSEntityList.get(0);
        if (smsAbleWhenExpired != null) {
            if (configGlobalSMSEntity.getSmsAbleWhenExpired() == null || configGlobalSMSEntity.getSmsAbleWhenExpired().longValue() != smsAbleWhenExpired.longValue()) {
                configGlobalSMSEntity.setSmsAbleWhenExpired(smsAbleWhenExpired);
            }
        }
        if (proAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getProAnAbleBeforeExpired() == null || configGlobalSMSEntity.getProAnAbleBeforeExpired().longValue() != proAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setProAnAbleBeforeExpired(proAnAbleBeforeExpired);
            }
        }
        if (proAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getProAnDayBeforeExpired() == null || configGlobalSMSEntity.getProAnDayBeforeExpired().longValue() != proAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setProAnDayBeforeExpired(proAnDayBeforeExpired);
            }
        }
        if (cityAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getCityAnAbleBeforeExpired() == null || configGlobalSMSEntity.getCityAnAbleBeforeExpired().longValue() != cityAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCityAnAbleBeforeExpired(cityAnAbleBeforeExpired);
            }
        }
        if (cityAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getCityAnDayBeforeExpired() == null || configGlobalSMSEntity.getCityAnDayBeforeExpired().longValue() != cityAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCityAnDayBeforeExpired(cityAnDayBeforeExpired);
            }
        }
        if (countyAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getCountyAnAbleBeforeExpired() == null || configGlobalSMSEntity.getCountyAnAbleBeforeExpired().longValue() != countyAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCountyAnAbleBeforeExpired(countyAnAbleBeforeExpired);
            }
        }
        if (countyAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getCountyAnDayBeforeExpired() == null || configGlobalSMSEntity.getCountyAnDayBeforeExpired().longValue() != countyAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCountyAnDayBeforeExpired(countyAnDayBeforeExpired);
            }
        }
        if (streetAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getStreetAnAbleBeforeExpired() == null || configGlobalSMSEntity.getStreetAnAbleBeforeExpired().longValue() != streetAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setStreetAnAbleBeforeExpired(streetAnAbleBeforeExpired);
            }
        }
        if (streetAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getStreetAnDayBeforeExpired() == null || configGlobalSMSEntity.getStreetAnDayBeforeExpired().longValue() != streetAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setStreetAnDayBeforeExpired(streetAnDayBeforeExpired);
            }
        }
        configGlobalSMSDao.save(configGlobalSMSEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
    }
}
